<?php

namespace Litecms\BusManageList\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BusManageList\Models\BusManageList;

class BusManageListPolicy
{

    /**
     * Determine if the given user can view the bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function view(UserPolicy $user, BusManageList $bus_manage_list)
    {
        if ($user->canDo('bus_manage_list.bus_manage_list.view') && $user->isAdmin()) {
            return true;
        }

        return $bus_manage_list->user_id == user_id() && $bus_manage_list->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bus_manage_list.bus_manage_list.create');
    }

    /**
     * Determine if the given user can update the given bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function update(UserPolicy $user, BusManageList $bus_manage_list)
    {
        if ($user->canDo('bus_manage_list.bus_manage_list.edit') && $user->isAdmin()) {
            return true;
        }

        return $bus_manage_list->user_id == user_id() && $bus_manage_list->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BusManageList $bus_manage_list)
    {
        return $bus_manage_list->user_id == user_id() && $bus_manage_list->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BusManageList $bus_manage_list)
    {
        if ($user->canDo('bus_manage_list.bus_manage_list.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bus_manage_list.
     *
     * @param UserPolicy $user
     * @param BusManageList $bus_manage_list
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BusManageList $bus_manage_list)
    {
        if ($user->canDo('bus_manage_list.bus_manage_list.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
