<?php

namespace Litecms\BusManageList\Providers;

use Illuminate\Support\ServiceProvider;

class BusManageListServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'bus_manage_list');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'bus_manage_list');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.bus_manage_list', function ($app) {
            return $this->app->make('Litecms\BusManageList\BusManageList');
        });

                // Bind BusManageList to repository
        $this->app->bind(
            'Litecms\BusManageList\Interfaces\BusManageListRepositoryInterface',
            \Litecms\BusManageList\Repositories\Eloquent\BusManageListRepository::class
        );

        $this->app->register(\Litecms\BusManageList\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\BusManageList\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\BusManageList\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.bus_manage_list'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/bus_manage_list.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/bus_manage_list')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/bus_manage_list')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
